from bluer_objects.README.items import ImageItems

from bluer_ugv.README.rangin.consts import rangin_assets2

docs = [
    {
        "path": "../docs/rangin/specs.md",
        "items": ImageItems(
            {
                f"{rangin_assets2}/20251116_124842.jpg": "",
            }
        ),
    },
]
