from bluer_ugv.README.rangin import (
    mechanical,
    operation,
    parts,
    power,
    root,
    schematics,
    specs,
    terraform,
)

docs = (
    mechanical.docs
    + operation.docs
    + parts.docs
    + power.docs
    + root.docs
    + schematics.docs
    + specs.docs
    + terraform.docs
)
