from bluer_objects.README.consts import assets_url, designs_url


swallow_assets2 = assets_url(
    "swallow",
    volume=2,
)

swallow_designs = designs_url("swallow")

swallow_electrical_designs = designs_url("swallow/electrical")

swallow_mechanical_designs = designs_url("swallow/mechanical")

swallow_ultrasonic_sensor_designs = designs_url("swallow/ultrasonic-sensors")
