C = 343.0  # speed of sound (m/s)
CYCLE_MIN_S = 0.060  # ≥60 ms per datasheet
TRIG_PULSE_S = 30e-6  # 30 µs trigger
WAIT_HIGH_TIMEOUT_S = 0.025  # 25 ms to see rising edge
WAIT_LOW_TIMEOUT_S = 0.040  # 40 ms max pulse width
