import os
from bluer_options.env import load_config, load_env, get_env

load_env(__name__)
load_config(__name__)

BLUER_UGV_MOUSEPAD_ENABLED = get_env(
    "BLUER_UGV_MOUSEPAD_ENABLED",
    0,
)

BLUER_UGV_BEAST_MODEL = get_env(
    "BLUER_UGV_BEAST_MODEL",
)

BLUER_UGV_CAMERA_ACTION_PERIOD = get_env(
    "BLUER_UGV_CAMERA_ACTION_PERIOD",
    1.5,
)
BLUER_UGV_CAMERA_TRAINING_PERIOD = get_env(
    "BLUER_UGV_CAMERA_TRAINING_PERIOD",
    3.0,
)

BLUER_UGV_SWALLOW_NAVIGATION_DATASET_LIST = get_env(
    "BLUER_UGV_SWALLOW_NAVIGATION_DATASET_LIST"
)

BLUER_UGV_SWALLOW_NAVIGATION_MODEL = get_env(
    "BLUER_UGV_SWALLOW_NAVIGATION_MODEL",
)

BLUER_UGV_SWALLOW_STEERING_SETPOINT = get_env(
    "BLUER_UGV_SWALLOW_STEERING_SETPOINT",
    50,
)

BLUER_UGV_SWALLOW_STEERING_EXPIRY = get_env(
    "BLUER_UGV_SWALLOW_STEERING_EXPIRY",
    0.05,
)

BLUER_UGV_SWALLOW_STEERING_EXPIRY_YOLO = get_env(
    "BLUER_UGV_SWALLOW_STEERING_EXPIRY_YOLO",
    0.1,
)

BLUER_UGV_SWALLOW_STEERING_EXPIRY_ETHERNET = get_env(
    "BLUER_UGV_SWALLOW_STEERING_EXPIRY_ETHERNET",
    0.3,
)

BLUER_UGV_SWALLOW_YOLO_SPEED_SETPOINT = get_env(
    "BLUER_UGV_SWALLOW_YOLO_SPEED_SETPOINT",
    20,
)

BLUER_UGV_SWALLOW_YOLO_DATASET_LIST = get_env(
    "BLUER_UGV_SWALLOW_YOLO_DATASET_LIST",
)

BLUER_UGV_SWALLOW_YOLO_MODEL = get_env(
    "BLUER_UGV_SWALLOW_YOLO_MODEL",
)

BLUER_UGV_ULTRASONIC_SENSOR_DANGER_THRESHOLD = get_env(
    "BLUER_UGV_ULTRASONIC_SENSOR_DANGER_THRESHOLD",
    500.0,
)
BLUER_UGV_ULTRASONIC_SENSOR_WARNING_THRESHOLD = get_env(
    "BLUER_UGV_ULTRASONIC_SENSOR_WARNING_THRESHOLD",
    800.0,
)

BLUER_UGV_ULTRASONIC_SENSOR_TEST_OBJECT = get_env(
    "BLUER_UGV_ULTRASONIC_SENSOR_TEST_OBJECT"
)

BLUER_UGV_ULTRASONIC_SENSOR_ENABLED = get_env(
    "BLUER_UGV_ULTRASONIC_SENSOR_ENABLED",
    1,
)

BLUER_UGV_ULTRASONIC_SENSOR_MAX_M = get_env(
    "BLUER_UGV_ULTRASONIC_SENSOR_",
    0.80,
)

BLUER_UGV_ULTRASONIC_SENSOR_KEEP_LOG = get_env(
    "BLUER_UGV_ULTRASONIC_SENSOR_KEEP_LOG",
    1,
)

BLUER_UGV_ULTRASONIC_SENSOR_LOG = get_env(
    "BLUER_UGV_ULTRASONIC_SENSOR_LOG",
    1,
)

RANGIN_VIDEO_LIST_OBJECT = get_env(
    "RANGIN_VIDEO_LIST_OBJECT",
)

BLUER_UGV_RELEASE_2 = get_env(
    "BLUER_UGV_RELEASE_2",
)

BLUER_UGV_AUDIO_LANGUAGE = get_env(
    "BLUER_UGV_AUDIO_LANGUAGE",
    "fa",
)
BLUER_UGV_AUDIO_CHANNELS = get_env(
    "BLUER_UGV_AUDIO_CHANNELS",
    1,
)
BLUER_UGV_AUDIO_RATE = get_env(
    "BLUER_UGV_AUDIO_RATE",
    48000,
)
BLUER_UGV_AUDIO_LENGTH = get_env(
    "BLUER_UGV_AUDIO_LENGTH",
    30,
)

BLUER_UGV_ETHERNET_PORT = get_env(
    "BLUER_UGV_ETHERNET_PORT",
    5050,
)

BLUER_UGV_SWALLOW_SCENARIO = get_env(
    "BLUER_UGV_SWALLOW_SCENARIO",
    "swallow",
)
