from bluer_objects.README.consts import assets_url, designs_repo


rangin_assets2 = assets_url(
    suffix="rangin",
    volume=2,
)

rangin_electrical_design = f"{designs_repo}/blob/main/rangin/electrical"

rangin_mechanical_design = f"{designs_repo}/blob/main/rangin"
